---
title: Pan-Arctic Ocean primary production constrained by turbulent nitrate fluxes
tblPrefix: Table
numbersections: true
---
[comment]: # (This document has preprocessor directives baked into it. In an expression like {~~ABC~>XYZ~~}, the preprocessor (essentially a perl one-liner) will choose ABC for a “static” version of the paper, including png figures, whereas it will choose the second expression (XYZ) to compile an interactive paper where figures (in an html format) can be zoomed, panned, and otherwise interactively explored, depending on each particular figure.)

{~~~>This is an enhanced version of the paper of the same name. The main difference is that most figures in this document can be explored interactively using zooming, panning, and additional information in tooltips.~~}


**Achim Randelhoff**¹²\*, **Johnna Holding**³⁴, **Markus Janout**⁵, **Mikael Kristian Sejr**³⁴, **Marcel Babin¹²**, **Jean-Éric Tremblay**¹², **Matthew B. Alkire**⁶⁷

¹ Takuvik Joint International Laboratory, Université Laval (QC, Canada) and CNRS (France)

² Département de biologie and Québec-Océan, Université Laval (QC, Canada)

³ Arctic Research Centre, Aarhus University, Ny Munkegade 114, bldg. 1540, 8000 Aarhus C, Denmark

⁴ Department of Bioscience, Aarhus University, Vejlsøvej 25, 8600, Silkeborg, Denmark

⁵ Alfred-Wegener-Institute Helmholtz Center for Polar and Marine Research, Am Handelshafen 12, D-27570 Bremerhaven, Germany

⁶ Applied Physics Laboratory, University of Washington, Seattle, WA USA

⁷ Now at: School of Oceanography, University of Washington, Seattle, WA USA

\* **Correspondance**:

Achim Randelhoff, achim.randelhoff@takuvik.ulaval.ca

**Keywords**: Arctic, turbulence, nitrate, flux, primary production, climate change, sea ice

**Abstract**

Arctic Ocean primary productivity is limited by light and inorganic nutrients. With sea ice cover declining in recent decades, nitrate limitation has been speculated to become more prominent. Although much has been learned about nitrate supply from general patterns of ocean circulation and water column stability, a quantitative analysis requires dedicated turbulence measurements that have only started to accumulate in the last dozen years. Here we present new observations of the turbulent vertical nitrate flux in the Laptev Sea, Baffin Bay, and Young Sound (North-East Greenland), supplementing a compilation of 13 published estimates throughout the Arctic Ocean. Combining all flux estimates with a Pan-Arctic database of in situ measurements of nitrate concentration and density, we found the annual nitrate inventory to be largely determined by the strength of stratification and by bathymetry. Nitrate fluxes explained the observed regional patterns and magnitudes of both new primary production and particle export on annual scales. We argue that with few regional exceptions, vertical turbulent nitrate fluxes can be a reliable proxy of Arctic primary production accessible through autonomous and large-scale measurements. They may also provide a framework to assess nutrient limitation scenarios based on clear energetic and mass budget constraints resulting from turbulent mixing and freshwater flows.

# Introduction

Without upward mixing of nutrients, much of the ocean would harbour no life [@ambuehl1959bedeutung; @margalef1978life]; the Arctic Ocean is no exception. As dead algae and other particulate matter have the tendency to sink due to their higher density, nutrients are constantly removed from surface waters. Phytoplankton therefore relies on a resupply of nutrients to grow and re-build its standing stock every year. Consequently, primary production, occurring in the euphotic zone where light levels are sufficient to support net growth, is controlled by the vertical flux of new nutrients from below the photic zone each year and thus available to new production, i.e. uptake of allochthonous nitrate [see Appendix and @dugdale1967uptake].

While turbulence is an important factor for aquatic life everywhere, the Arctic Ocean is special in certain regards such as a ubiquitous sea ice cover and strong stratification [@aagaard1989role]. Large summertime accumulation of meltwater from sea ice and terrestrial runoff has profound impacts on vertical mixing in the upper ocean [@mcphee1989generation; @randelhoff2017turbulent; @cole2018internal]. In winter, brine rejection from freezing ice weakens stratification and creates turbulence [@mcphee1996unstable]. We will show throughout this paper that winter mixing is disproportionately important for setting mixed-layer properties.

Sea ice is often assumed to be a rather rigid lid [@padman1995smallscale] that shuts out a large portion of the sunlight as well as wind energy that could otherwise mix the ocean. With continued decline of sea ice extent and thickness in the 21st century [@stroeve2012arctics; @comiso2012large; @meier2014arctic], the factors limiting Arctic marine growth will likely change. Such a transition in limiting factors usually leads to difficulties in predicting systems [@allen2015unified]. Indeed, @vancoppenolle2013future found that three different coupled biogeochemical general circulation models and their predictions for integrated Arctic Ocean primary production until the end of this century show diverging trajectories with opposite trends beyond a few decades from now. In their analysis, a prominent uncertainty concerned the evolution of the nitrogen pool in the photic zone. Yet since phytoplankton growth is a rate and not a stock, one should ideally measure the nitrogen flux, not its concentration at a given time, to determine primary production in the long term. Our lack of understanding of the vertical nitrate flux has resulted in the failure to consistently predict future Arctic Ocean primary production.

Stratification inhibits vertical mixing [@osborn1980estimates] and consequently vertical turbulent nitrate fluxes. The Arctic Ocean can be divided into a weakly stratified Atlantic sector and a strongly stratified Pacific one [e.g. @carmack2007alphabeta; @bluhm2015tale; @tremblay2015global]. Vertical turbulent nitrate fluxes are therefore routinely invoked to explain patterns of primary production across the Arctic, such as basin scale differences [@carmack2006climate; @tremblay2015global; @randelhoff2016regional], but also an apparently increasing prevalence of fall blooms [@ardyna2014recent; @nishino2015nutrient] and even fjord scale differences depending on glacier morphology [@hopwood2018non]. These observations are mostly qualitative and rarely quantified with direct measurements. Whereas the vertical nitrate flux in the world ocean has received attention at least since the late 1980s [@lewis1986vertical], dedicated measurements in the Arctic Ocean have only started to accumulate in the last dozen years. We use this opportunity to summarize the current state of knowledge and investigate the role of vertical turbulent nitrate fluxes in regulating Arctic marine productivity. Interestingly, we find that vertical mixing largely explains marine primary productivity at the pan-Arctic scale. Finally, we outline further research directions to unify physical constraints of Arctic Ocean primary production.

# Material & methods

This study compiles measurements and estimates of the upward vertical turbulent flux of nitrate in different locations across the Arctic Ocean. We present four new estimates of the turbulent vertical nitrate flux, along with a dozen more values derived from the literature. We further supplement the nitrate fluxes with a collection of vertical profiles of seawater nitrate concentration.

## Compilation of NO₃⁻ concentrations

The Pan-Arctic data base carefully compiled by @codispoti2013synthesis was downloaded from the NOAA website under NODC accession number 0072133. An additional database covered the Canadian Archipelago using various ArcticNet and Department of Fisheries and Oceans Canada cruises, compiled by Coupel et al. (2020, in prep.). We included more winter data, notoriously scarce in the Arctic, by downloading data from the Chukchi shelf as presented by @arrigo2017late. For each profile, we derived (1) the Brunt-Väisälä buoyancy frequency in the depth interval from 30 to 60 m as an indicator of the strength of stratification and (2) the surface nitrate concentration.
For the latter, only profiles were used where the depth of the shallowest nitrate measurement was at most 15 m. The shallowest nitrate measurement was then extrapolated to the surface (0 m depth), after which values were averaged over the interval 0-15 m.

## Compilation of turbulent vertical nitrate fluxes

In order to compile previously published estimates of vertical turbulent nitrate fluxes in the Arctic Ocean, we relied mostly on our knowledge of the literature, given the small amount of relevant publications. Additionally, we performed a search on Web of Science (Clarivate Analytics) using the search term `TS=((nitr* AND suppl*) OR (nitr* AND flux*) OR (nitr* AND mix*)) AND TS=((Arctic OR Polar) AND Ocean) AND TS=(vertical OR turbulen*) AND WC=Ocean*`, which resulted in 95 publications that were individually screened for relevance. We only included measurements and estimates based on in-situ observations.

The resulting list comprised just above a dozen flux estimates going back to less than ten publications. To improve data coverage, we present new vertical nitrate flux estimates from the Laptev Sea, Baffin Bay, and Young Sound, as well as a re-calculation of published observations from the Chukchi Sea [@nishino2015nutrient]. In order to not disrupt the flow of the main text, details of the respective methods and field campaigns are deferred to the Appendix.

Briefly, our three-week-long summer sampling campaign in Young Sound (a North East Greenland fjord) sought to quantify turbulent mixing, vertical nitrate supply, and new (nitrate-based) production in a fjord strongly stratified by meltwater from the Greenland Ice Sheet. From the Laptev Sea, we present a small selection of representative vertical profiles of nitrate concentrations and oceanic microstructure, collected in the years 2008-2018. From Baffin Bay, we made use of a novel year-long 2017-18 time series of autonomous profilers, so-called biogeochemical (BGC) Argo floats [@biogeochemical-argoplanninggroup2016scientific]. These were specially adapted in order to function under the ice cover lasting from November to July. Based on the evolution of the upper-ocean nitrate inventory, we inferred the part due to vertical mixing. We further used a data set of nitrate concentrations and turbulent microstructure in the Chukchi Sea [@nishino2015nutrient] to calculate another estimate of vertical nitrate fluxes during early fall.

For the majority of those experiments, turbulence (microstructure) data were measured; just as was the case for the literature values. In some cases, turbulent mixing was inferred from current finestructure; see also the Appendix. Nitrate fluxes were calculated across the nitracline, meaning by combining a nitracline-average turbulent diffusivity with the strength of the nitrate gradient. Individual methodologies may however vary regarding e.g. choice of vertical layer or averaging procedures. According to our personal experience, such choices may make a difference for individual calculations, but less so for large-scale averages, and therefore we take the fluxes recorded in the literature at face value. A systematic assessment of potential methodological errors has to our knowledge however not been conducted. For a more detailed discussion of how vertical nitrate fluxes are measured, and in particular the uncertainties and caveats that come with each method, see the Appendix.

For each of the estimates of the vertical turbulent nitrate flux across the nitracline and into the surface layer, we extracted the end-of-winter surface nitrate concentration either from the same publication or from related studies. We also classified each nitrate flux value as either "perennial stratification" or "winter overturning". The former means that surface layer stratification persisted year-round; the latter means that the winter mixed layer was significantly deeper than the meltwater-stratified summer surface layer. The classification was done based on perusal of the available literature. The full rationale with a detailed description of the vertical layering in relation to the nitrogen budget is given in the Appendix.

The specific references for each data point are given in the supplementary {~~material~>material~~}. Our entire data set is presented in @Tbl:nitrate_fluxes; note that it mixes vertical nitrate fluxes across different seasons, vertical levels, regions, and sample sizes.

## Comparison between nitrate fluxes and primary production

We compared nitrate fluxes with new production (primary production based on assimilation of nitrate, see @dugdale1967uptake) and export production. New production estimates were taken from @sakshaug2004primary. Export production estimates were taken from @wiedmann2015potential, who has compiled the vertical carbon export flux at 200 m depth. To enhance data coverage, we added measurements from two studies from the Central Arctic Ocean [@honjo2010biological; @cai2010low]. Details can be found in {~~the Supplementary Material~>[notebook C_primary_production.ipynb](../nb/C_primary_production.ipynb).~~}.

Both biomass and primary production are frequently given in units of carbon. To convert between units of carbon and nitrate fluxes, we employed a C:N ratio of 6.6 mol C: mol N, the so-called Redfield ratio [@redfield1963influence]. This particular choice of C:N ratio may be criticized on the grounds that it varies depending on the type of organic matter and other environmental factors [@brzezinski1985si; @tamelander2013new], and that C:N ratios observed in the Arctic in particular are usually higher [@frigstad2014variation]. However, turbulence measurements come with a much larger margin of error, with one detailed study giving the systematic bias between two different sets of microstructure probes, signal processing, and calibration procedures as within a factor of 2 [@moum1995comparison]. This is impressive for microstructure measurements but significantly larger than the precision with which the C:N ratio is frequently discussed in biogeochemical contexts. Therefore, by assuming a standard, constant C:N ratio, we make our results easy to adapt to other ratios should the reader want to change this number.

# Results

## Seasonal cycle of surface nitrate concentration

Winter surface nitrate concentrations in the Atlantic sector reached high values around 11 µM (@Fig:NO3-COMP_chart_seasonal_cycle). In the Central Arctic Ocean, concentrations stayed constant at roughly 1-3 µM throughout the year, whereas in the coastal Beaufort Sea they occasionally reached intermediate values in winter. Most regions of the Arctic however became nitrate limited (<1µM) during the summer, with the exception of the Eurasian Basin, the Makarov Basin, and some regions in Southern Fram Strait.


## Nitrate fluxes

Nitrate flux estimates are still scarce given that they require co-located measurements of both turbulence and nitrate concentrations; however, they approach Pan-Arctic coverage ([@Fig:FN-COMP_map]). Highest values (> 1 mmol N m⁻² d⁻¹) were found in the Atlantic sector. The lowest values (<< 0.1 mmol N m⁻² d⁻¹) occurred in the central basins (Canada Basin) and in Young Sound and the Laptev Sea, two locations strongly impacted by terrestrial freshwater.

## Nitrate flux seasonality

The seasonal cycle of surface nitrate concentration was also reflected in its upward fluxes (@Fig:FN-COMP_chart_seasonal_cycle). In areas where the water column overturned in winter, summer fluxes were an order of magnitude below winter values. A notable exception was observed at one station in the Barents Sea south of the polar front [@wiedmann2017upward], where the water was weakly stratified even in summer and hence nitrate fluxes were probably at least as high as in winter with 5 mmol N m⁻² d⁻¹ (@Tbl:nitrate_fluxes), although sample size (N=1) was not sufficient to draw further conclusions.

Observations over a full seasonal cycle were only available in areas where the water column overturns, notably in the Barents sea and shelf slope area (@Tbl:nitrate_fluxes). In contrast, in the non-overturning regions, fluxes were lower overall, but there is not enough data to test whether the seasonality itself is, in relative terms, really much weaker there.

# Discussion

## Nitrate fluxes as a function of stratification and seasonality

The vertical nitrate flux (F$_N$) in winter was remarkably well correlated with the pre-bloom nitrate surface concentration \[NO$_3^-$\]$_0$ ([@Fig:FN-COMP_chart_vs_NO3]A). A linear model \[NO$_3^-$\]$_0$ = 7.6µM + 3.4µM$\cdot$log$_{10}$(F$_N$/mmol N m⁻² d⁻¹) yielded an adjusted $R^2$=0.85 and p=0.002 for the linear coefficient. Consequently, deep winter mixing, where it occurs, likely is a controlling factor of the annual nitrate inventory, expanding on direct measurements of a full annual cycle over the Barents Sea shelf break [@randelhoff2015seasonal]. Our results quantitatively support the perception that vertical nitrate fluxes explain the seasonality of the upper ocean nitrate inventory, as has been surmised multiple times in the literature [see e.g. @carmack2006food; @tremblay2015global] based on general considerations of stratification and bathymetry.

Stratification and bathymetry also governed pre-bloom surface nitrate concentrations ([@Fig:FN-COMP_chart_vs_NO3]B) and, by extension from the aforementioned, vertical nitrate fluxes. Stratification represents the resistance of the water column against overturning and vertical mixing, making its link to vertical nitrate fluxes explicit. As for bathymetry, locations with the same strength of upper-ocean stratification had on average consistently highest pre-bloom nitrate over the shelf slope (200 m < depth < 1500 m), lower on the shelves (< 200 m), and lowest over the basins (>1500 m). These findings correspond to general expectations as rough or shallow topography lets currents interact with the bathymetry. Mixing in the Arctic has indeed been found to be especially elevated over the shelf slope [@rippeth2015tidemediated]. Tidal velocities are generally higher over the shelves than over the deep basins [@kowalik2013arctic]. The Arctic boundary current close to the shelf break may also provide opportunities for localized upwelling through interaction with topography or wind [@carmack2003wind; @kampf2016upwelling].

## Primary production constrained by nitrate fluxes

### Annual basin-scale productivity

Nitrate supply should constrain primary production. Regenerated production is a large if not dominant fraction of primary production where nitrogen is scarce and is therefore not directly related to nitrate fluxes, unlike new production, which relies on nitrate brought up from below the photic zone [@dugdale1967uptake]. In the absence of significant advection, new production is even stipulated to be similar to the upward nitrate flux based on conservation of mass alone (see Appendix, @Fig:ncycle).

On annual time scales, both the upward nitrate flux in winter into the surface mixed layer, the particle export at 200 m depth, and new production (nitrate uptake) matched up reasonably well for Baffin Bay, the Barents Sea, the Southern Beaufort Sea, and the Central basin (@Fig:PP_FN_NEWP_EXP_regional), both in regional patterns and order of magnitude. (Other regions lack estimates of the winter nitrate flux.) Indeed, annual budgets have to be closed if nitrate inventories are not to change in the long term. The relatively minor differences between export production, new production, and the vertical nitrate flux may reflect the extreme disparity of spatial and temporal scales of the different measurements. However, no study has systematically investigated all three quantities on annual to interannual time scales and at the same location.

### Short-term new production

A different matter is whether or not during summer, upward mixing of nitrate limits the amount of new production in the short term. Here, the published literature gives a less clear picture ([@Fig:PP_incubations_vs_flux]A). @randelhoff2016vertical measured vertical nitrate flux and new production for both spring and summer in the marginal ice zone around northern Fram Strait. In spring, new production was considerably larger than vertical nitrate supply as nitrate was not yet depleted and hence did not limit photosynthesis. In summer, on the other hand, when the surface water was nitrate-depleted, new production was an order of magnitude _smaller_ than nitrate supply, contrary to the hypothesis.

A likely contribution to this discrepancy was the seasonal buildup of dissolved organic nitrogen  ([@Fig:PP_incubations_vs_flux]B) observed during the same field campaigns by @paulsen2018asynchronous. The nitrate uptake rate measurements by @randelhoff2016vertical only considered assimilation into the particulate pool due to methodological constraints. The simultaneous production of dissolved organic nitrogen could have diverted nitrate from the particulate to the dissolved production. However, even if there were an imbalance between supply and uptake of nitrate, the associated change in the nitrate concentration would be slow and necessitate Lagrangian measurements over weeks to detect them. Recycling of nitrogen in the microbial loop may turn out to be important when balancing nutrient fluxes with new production over short subseasonal time scales. @nishino2018biogeochemical found good agreement between upward nitrate flux, nitrate uptake, and export of particulate organic matter, based on a case study in the Chukchi sea. This may represent geographic differences in the dynamics of the system, or even in the methodology. @nishino2018biogeochemical used different methods from those of @randelhoff2016vertical, even though they neglected assimilation into the dissolved nitrogen pool as well [@shiozaki2009contribution].

Our measurements in Young Sound, North-East Greenland (see Appendix), gave a diametrically opposed perspective: Here, vertically integrated new production was significantly above the vertical turbulent supply of new nitrate in this extremely quiescent fjord. Overall productivity in Young Sound is therefore likely limited by strong stratification and weak vertical mixing [@holding2019seasonal]. Tidal mixing over the two shallow sills in concert with isopycnal mixing may contribute to overall upward nitrate supply [see e.g. @fer2014mixing], but terrestrial runoff may also contribute significantly to the nutrient cycling [@rysgaard2003physical] as nitrate concentrations in run-off water are higher than those measured in the sea surface [@paulsen2017carbon]. This scenario is likely specific to this fjord and cannot be generalized around Greenland as nitrate concentrations in Greenland Ice Sheet run-off often act to dilute surface nitrate concentrations [@meire2016high; @hopwood2019does].

In the same vein, but outside the Arctic Ocean, @law2001lagrangian and @rees2001carbon found that vertical mixing supplied only 33 % of the nitrate demand at a North Atlantic site, in agreement with a study by @horne1996turbulence in the Gulf of Maine. Even in the Mauritanian upwelling region, nitrate fluxes in excess of 100 mmol N m⁻² d⁻¹ accounted for only 10-25% of observed net community production [@schafstall2010tidalinduced]. More extremely, @shiozaki2011imbalance found that one location on the continental shelf of the East China Sea "exhibited a considerable discrepancy between the nitrate assimilation rate (1500 mmol N m⁻² d⁻¹) and vertical nitrate flux (98 mmol N m⁻² d⁻¹)", and they went so far as concluding that "the assumption of a direct relationship between new production, export production, and measured nitrate assimilation is misplaced, particularly regarding the continental shelf of the East China Sea".

The scarcity of dedicated measurements that evaluate both nitrate fluxes, new production, and organic nitrogen pools at relevant space-time scales is a major impediment to evaluating the direct impact of nitrate fluxes on primary productivity in the Arctic on time scales of days. However, given the correspondence we observed between new production and vertical nitrate supply over annual Pan-Arctic scales, any mismatch between the two on sub-seasonal time scales may be caused by asynchronous evolution of the different nitrogen pools ([@Fig:ncycle; @Fig:PP_incubations_vs_flux]B). Phytoplankton growth responses may also lag nutrient supply pulses, perhaps necessitating time series approaches when studying scales as short as weeks [@omand2012episodic].

## Nitrogen limitation of primary production

Nitrogen scarcity plays a large role in constraining Arctic marine primary production [@moore2013processes; @tremblay2015global]. Nutrient limitation of phytoplankton growth is usually quantified in terms of a _half-saturation constant_ (of a Michaelis-Menten kinetics), above which nutrient uptake rates benefit less and less from increasing ambient nutrient concentrations. Reported values of such half-saturation constants vary widely according to species and physiological state, but reasonable values usually range around orders of magnitude from 0.1 to 10 µM, but clustering around 1 µM [e.g. @eppley1969halfsaturation], with larger ones for larger cells [@chisholm1992phytoplankton] and values in the lower end for picophytoplankton [@cochlan1991kinetics; @agawin2000nutrient]. We infer that larger (usually bloom-forming) species are nitrate-limited in summer across large swaths of the Arctic, but not including some of the central basin, where summer surface concentrations are in excess of e.g. 5 µM in the Makarov and Nansen basins (@Fig:NO3-COMP_map_no3_summer). These high nitrate concentrations in the Central Arctic are usually taken to indicate regionally important light limitation by perennial sea ice cover [@codispoti2013synthesis].

A cautionary remark is in order regarding nitrate concentrations as indicators of potential growth. Since the nitrate supply, like phytoplankton growth, is a rate and not a stock, its present-day inventory alone does not yield sufficient information to infer possible limitations in future scenarios. Therefore the summer surplus nitrate observed in the central Arctic Ocean may only be available transiently while the ice cover shrinks, but not in a steady-state situation without summer sea ice.

In other words: If fall blooms are due to upward mixing of new nitrate, they increase new production in the short term. Whether such increases are long-term or if they instead serve to deepen the nitracline depends on the vertical mixing in winter. Similarly, a lengthening ice-free season or a more transparent ice cover lead to a deeper euphotic zone and could enhance growth in subsurface waters, richer in nutrients, but the resupply rate of nitrogen ultimately decides about potential lasting increases in new production.

## Future scenarios

@randelhoff2016regional provided estimates of end-of-century new production, given presently observed turbulence and potential future increases in the freshwater inventory observed in a numerical circulation model [@nummelin2015consequences]. They concluded that a potential increase in new production in the Amundsen Basin (if the system were to turn to nitrate limitation) may fall victim to future increases in vertical stability. Little is known about the future of seasonal and especially summertime stratification in the surface layer [@randelhoff2017turbulent].

Contrarily, @polyakov2017greater posited that an ongoing Atlantification will lead to deeper winter convection in the Eurasian Basin. As Atlantic Water is also the principal source of heat in the Arctic Ocean, it has been implicated in recent sea ice loss [@ivanov2016arctic; @polyakov2017greater], and hence could regionally relieve nutrient and light limitation at the same time [@randelhoff2018seasonality]. The recent decreases of sea ice extent in Northern Fram Strait and north of Svalbard [@onarheim2018seasonal] indicate that such a process is already well underway. The analogue may be happening in the Chukchi sea, where the Alaskan Coastal Current brings in both large amounts of heat [@woodgate2012observed] and nutrients [@torres-valdes2013export], but the published literature is less clear on the presence and effects of such a tentative advective borealization of the Chukchi Sea.

## Ice cover and wind-driven turbulence

The published literature is also equivocal on whether or not the decreasing ice cover will enhance turbulent mixing in the upper ocean. While less sea ice may enhance the input of wind energy into the ocean [@rainville2009observations; @dosser2016dynamics], this energy may be dissipated at shallow depths due to the strong stratification [@lincoln2016wind]. Reanalysis of conductivity-temperature depth and acoustic Doppler current profiler finestructure data has not shown trends in turbulent mixing in recent decades [@guthrie2013revisiting; @chanona2018variability].

Broken-up, free-drifting sea ice in summer may enhance wind energy input into the upper ocean compared to ice-covered areas by enhancing surface roughness [@martin2016impact] but also decrease vertical turbulent mixing in the surface layer through the associated layer of meltwater [@randelhoff2016vertical; @randelhoff2017turbulent]. Larger freezing rates, caused by increasing proportions of first-year ice, may increase upward mixing, but the potential effects on entrainment of nitrate into the surface layer has to our knowledge not been systematically studied. A major uncertainty in any future prognoses is the scarcity of large-scale surveys of the ice-ocean boundary layer.

## Arctic nitrate fluxes in a global context

Based on a literature review  (@Tbl:nitrate_fluxes_other), Arctic vertical nitrate fluxes tend to be approximately one order of magnitude lower than in the rest of the world ocean (@Fig:FN-COMP_comparison_world). Even though study sites in the global ocean may be biased by measurements seeking to explain high biological productivity (most often as the result of strong mixing and upwelling), there is a considerable difference between new production in the Arctic Ocean and the world's most productive areas.

# Conclusions

## Summary

1. Determining nitrate fluxes is a laborious task. With measurements accumulating through the last 10 years, we are now approaching a Pan-Arctic baseline. In individual regions however, seasonal coverage remains patchy.
1. Arctic nitrate fluxes are, on average, one to two orders of magnitude smaller than those observed elsewhere in the world ocean.
1. The spatial patterns of the upper ocean nitrate inventory in the Arctic are well explained by vertical nitrate fluxes.
1. On annual timescales, nitrate fluxes are a powerful tool to constrain export fluxes and new production, both of which are hard to measure autonomously.
1. On weekly or shorter timescales, the relation between nitrate supply and new production is unclear, mostly due to lack of appropriate time series data. A certain asynchronicity between the different nitrogen pools may confound budget calculations.

## Avenues for further research

Besides further aggregate scale (seasonal or basin-scale) measurements of the turbulent vertical nitrate flux, two avenues emerge from our conclusions.

1. Advances in turbulence-ecosystem coupling will require dedicated or autonomous sampling and time series. Purely physics-oriented turbulence sampling often does not sufficiently resolve the biologically relevant surface layer.
1. Prediction of upper ocean mixing and ice-ocean interaction depends on sea ice melt and freeze rates, expressed as buoyancy fluxes or in units of meters of freshwater equivalent per unit area. Yet, to our knowledge, this quantity is not routinely investigated as output of coupled ice-ocean circulation models and so no such data product exists that could aid in the extrapolation of Pan-Arctic patterns of the seasonal vertical nitrate flux.

## Upscaling primary production measurements

While currently publicly available datasets may be more comprehensive for new and export production than for nitrate fluxes, they possess some drawbacks concerning evaluating large-scale patterns. As incubations to determine new production are usually point measurements, averaging them is not trivial. Sediment traps, while measuring export fluxes at a single location, integrate the time dimension, and so are more representative, but also require a large logistic effort. Chemical tracer approaches [e.g. @moran2003does] make the data acquisition phase easier, but still require water samples and are hence not easily amenable to autonomous exploration. In sum, current Arctic Ocean exploration does not scale well. Nitrate fluxes, on the other hand, can be estimated purely based on physical sensor data and hence with larger scope both in time and space.

Such turbulence measurements do not necessarily have to be conducted using microstructure profilers - mixing can also be estimated from current shear or density strain fine-structure with more standard instruments, which may work especially well in discerning relative magnitudes but can also be calibrated using regional microstructure estimates [@gargett2008determining; @guthrie2013revisiting; @polzin2014finescale; @chanona2018variability]. Parameterizations of this kind, relying on models of internal wave breaking, are most useful away from boundaries, in scenarios of perennial stratification where year-round background fluxes dominate [@randelhoff2016regional], and less so to characterize near-surface mixing. Other promising avenues are approaches based on turbulence structure functions [@wiles2006novel], high-frequency Acoustic Doppler Current Profiler measurements, or microstructure sensors deployed on moorings and gliders [@scheifele2018measuring].

Turbulence also obeys tight physical constraints imposed by wind, tidal and other energy available for mixing, and by the freshwater (density) fluxes that cause background stratification. Nitrate fluxes may therefore be more easily constrained than plankton photophysiology that is notoriously variable across species and environmental conditions [e.g. @bouman2018photosynthesisirradiance].

## Perspectives

This study has focused on vertical diffusive transport, largely ignoring other transport modes. Upwelling [@carmack2003wind; @kampf2016upwelling], horizontal advection [@torres-valdes2013export], mesoscale eddy shedding [@watanabe2014enhanced], benthic processes [@renaud2015future], and river biogeochemistry [@frey2009impacts] all likely affect Arctic Ocean primary production at least regionally. The fact that Pan-Arctic patterns of primary production can seemingly be explained without the need to invoke any of these mechanisms also showcases the stark contrasts between the different Arctic regimes that likely shadow intra-regional nuances.

Mesoscale turbulence can contribute to cross-shelf transport and nutrient supply in the Chukchi sea [@watanabe2014enhanced]. Some studies suggest that eddies may also contribute to cross-shelf transport along the West Spitsbergen Current [@hattermann2016eddy]. @crews2018mesoscale found eddies may contribute to ventilation of halocline waters in the European Arctic, meaning they would be apparent in the upward vertical fluxes measured out of the halocline waters instead of contributing directly to mixed-layer nitrate pools. @johnson2010nitrate, working in the Subtropical North Pacific, stressed the importance of event-driven upward nitrate transport not easily captured by vertical diffusivities, and even the possibility of immediate utilisation of nitrate in an otherwise diabatic isopycnal excursion, for example associated with a passing eddy. Attention is required summing these contributions, however, as there is a certain danger of double counting nitrate fluxes in eddies [@martin2001mechanisms; @martin2003estimates].

Advection with ocean currents manifests itself largely as transport with the Pacific and Atlantic currents that e.g. @torres-valdes2013export have discussed. For the most part, these currents are subducted under local (Arctic) water masses and can hence be accounted for as part of the vertical fluxes downstream. @randelhoff2016vertical have argued that as these currents come from further south where primary production starts earlier and terminates later, the surface waters they carry are as nutrient-depleted as the Arctic surface waters. This argument has, however, never been tested quantitatively. Similarly, upwelling along coasts, shelf breaks, in eddies, and at marine-terminating glaciers may contribute regionally to ocean productivity [@carmack2003wind; @kampf2016upwelling; @meire2017marineterminating]. Arguments as to how exactly upwelling is caused and how it impacts nutrient fluxes have largely remained qualitative [@randelhoff2018short; but see @spall2014role for a careful modelling exercise].

Lastly, turbulent mixing is much more than only the vertical nitrate flux. It affects predator-prey interactions [@kiorboe2008mechanistic], nutrient uptake rates at the cell level [@karp-boss1996nutrient], light exposure of individual cells [@sverdrup1953conditions], etc. In fact, mixing and variability is a resource in itself that can be exploited by different plankton life strategies [@margalef1978life]. These concepts may turn out to be important in particular when interpreting regional specifics such as biological hotspots. As methods advance and measurements accumulate, we expect that more efforts can be dedicated to studying regional phenomena in a Pan-Arctic unified manner.

# Conflict of Interest

The authors declare that the research was conducted in the absence of any commercial or financial relationships that could be construed as a potential conflict of interest.

# Author Contributions

AR designed the study, made all visualizations, and wrote the first draft of the manuscript. AR, JH, and MKS conducted field sampling and data analysis of the Young Sound data. MBA and MJ sampled and analyzed the Laptev Sea data. MB lead the acquisition of the Baffin Bay data. JET contributed Canadian Archipelago nutrient data. All authors commented on the manuscript.

# Funding

Data acquisition of BGC-Argo Floats in Baffin Bay was funded through the NAOS project. Work in Young Sound was supported by the DANCEA project "De-icing Arctic coasts" and the Greenland Ecosystem Monitoring Programme. AR was supported by the Sentinel North program of Université Laval, partly funded by the Canada First Research Excellence Fund, and Carbon Bridge, a Polar Programme (project 226415) funded by the Norwegian Research Council. JMH was supported by the European Commission H2020 programme under the Marie Skłodowska-Curie Actions (GrIS-Melt: grant no. 752325). MBA was supported by the National Science Foundation (PLR-1203146 AM003) and the National Oceanic and Atmospheric Administration (NA15OAR4310156).

# Acknowledgments

The present paper started taking shape around the 4th "Symposium on Pan-Arctic Integration", held in Motovun, Croatia, 2017, and we thank all participants for inspiring discussions. We also thank two anonymous reviewers for their help.

We thank Andrey Novikhin (AARI) for preparing the nutrient measurements from the Laptev Sea shelf, Xiaogang Xing for quality-controlling and calibrating the Baffin Bay BGC Argo data, and Jørgen Bendtsen and Torben Vang for providing Young Sound bathymetry data. We are further grateful to Shigeto Nishino for clarifying discussions about his work in the Chukchi Sea.

Data exploration and visualization relied heavily on the [Holoviews library](http://holoviews.org) [@stevens2015holoviews].

# Supplementary Material

The supplemental material, accessible at [https://github.com/poplarShift/arctic-nitrate-fluxes](https://github.com/poplarShift/arctic-nitrate-fluxes), contains:

- The python code necessary to reproduce all analyses and figures, licensed under GNU GPL3.
- The data, as plotted in all figures, in machine-readable formats.
{~~- An interactive version of this article where figures can be zoomed, panned, and selectively highlighted (as appropriate) leveraging the [Bokeh library](http://bokeh.pydata.org) [@bokehdevelopmentteam2018bokeh].~>~~}

# Data Availability Statement

All data that were published for the first time in this study are included with the above repository. The rest are included to the extent possible.

# Appendix

## The marine nitrogen cycle

Discussions of ocean surface nitrogen budgets center around the marine nitrogen cycle. @Fig:ncycle shows a simplified version adapted to Arctic conditions. The main component is the cycling between inorganic nitrate and particulate organic nitrogen (PON). Upward transport of NO₃⁻ compensates nitrate uptake by algae into PON [@dugdale1967uptake] and subsequent sinking of this organic matter. The loop is closed by remineralization into nitrate at depth. When nitrogen is scarce in the surface layer, there is also intense recycling of nitrogen that has already been assimilated into organic matter, which is called regenerated production.

Additional complexity arises from a number of sources, sinks, and recycling processes not accounted for in this simplistic view. One of the conclusions of the present study is that we do not need to invoke those processes to understand Arctic surface layer budgets on a Pan-Arctic scale. Riverine inputs of nitrate are thought to be sufficiently small to be neglected at larger-than-regional scales [see e.g. @tank2012processing]. Some of the produced PON is also harvested e.g. by higher trophic levels or fisheries [e.g. @valiela2015marine], although the latter process is likely only regionally important, e.g. in the Barents Sea. Other factors may be important depending on the regional scope. Advection, upwelling, and mesoscale mixing have already been discussed in the main text. Nitrification, denitrification, and nitrogen fixation are in general not well constrained in the Arctic Ocean [@tremblay2008vertical; @blais2012nitrogen; @sipler2017preliminary]. @randelhoff2015seasonal, for instance, argued that winter vertical turbulent nitrate fluxes in areas with deep mixing are likely much larger than nitrification, but did so based on sparse data. A complete assessment of all these factors is beyond the scope of this paper.

## The vertical layering of Arctic Ocean nitrate

Fluxes are easiest to measure across strong gradients. A given vertical profile of nitrate concentrations in the Arctic Ocean can schematically be vertically divided by two nitraclines ([@Fig:ncycle]A): First, a seasonal one, which marks the transition from surface waters, modulated by seasonal freshwater from ice melt or terrestrial runoff and algal growth, to the remnant winter mixed layer. Second, and mostly present in the deep basins of the Arctic Ocean, one that we dub "perennial" as it is not eroded and re-established on an annual basis.

The seasonal nitracline may be completely mixed during winter ([@Fig:ncycle]B), rendering fluxes hard to estimate using the "diffusivity times gradient" formula. Across the perennial nitracline, fluxes can be estimated year-round stipulating the seasonal variations in nitracline dissipation are minor, a method exploited by @randelhoff2016regional to estimate Pan-Arctic patterns of upward nitrate supply in the deep basin. In practice, the two nitraclines are often not clearly delineated. The distinctive characteristics of the two nitraclines are most easily seen in the Eurasian Basin, where deep winter mixed layers are clearly separated from underlying Atlantic Waters. In the Canadian Basin, strong stratification prevents winter mixing from penetrating deep into the nitracline [@peralta-ferriz2015seasonal], leading to relatively small seasonal excursions in surface nutrient concentrations and a less distinct winter remnant mixed layer ([@Fig:ncycle]C).

Consequently, we classified the seasonality of all vertical nitrate flux estimates discussed in this paper in terms of whether the water column mixes deeply ("overturns") in winter or not (in which case stratification is dubbed "perennial"). We used the published literature for each location as well as the data set corresponding to the flux estimate, if available. Importantly, our classification is generally well-founded but occasionally ad-hoc and tentative due to sparse data. An illustrative example are three summertime flux estimates north of the Barents sea polar front [@sundfjord2007observations; @wiedmann2017upward]. For instance, @loeng1991features indicates a weak but persistent salinity stratification in the Arctic water mass throughout winter, but the few vertical nitrate profiles available in our compiled data set indicate a seasonal cycle of surface nitrate in line with what is seen south of the Polar Front. These three fluxes were hence classified as being in a location where the water column overturns in winter because we focused on the vertical structure of nitrate profiles. Either way, because all three fluxes were based on a small sample size, not too much weight was given to them in the overall analysis.


## Measuring vertical nitrate fluxes

Barring regionally important processes such as upwelling and eddy pumping [@carmack2003wind; @kampf2016upwelling; @randelhoff2018short], the most prevalent form of the upward transport of nitrate in the ocean is turbulent diffusion [@lewis1986vertical]. Such diffusion mixes the spent surface waters with deeper, more nutrient-rich waters, thereby replenishing their nitrate reservoir. A vertical turbulent nitrate flux is, by definition, the product of a so-called "diapycnal eddy diffusivity" with the vertical gradient of nitrate. This is completely analogous to any other tracer such as temperature or salinity. The interested reader is referred to the vast literature on turbulent flows.

To estimate both those quantities, one has to measure the turbulence and a vertical profile of nitrate concentrations at the same time and location. Determining nitrate concentrations is comparatively uncomplicated because only the non-turbulent background is needed; one can use either bottle samples or, preferably, optical nitrate sensors to achieve a better vertical resolution [@alkire2010sensorbased; @randelhoff2016vertical]. Both of these options are easily integrated into standard sampling with a CTD rosette. While care should be taken to calibrate the absolute concentrations of optical sensors against water samples, such biases are usually depth-independent and hence do not matter for the calculation of the gradients [see Appendix of @randelhoff2016vertical]. Measuring turbulence is more challenging because it requires either measurements with sophisticated instruments, requiring dedicated ship time and personnel, or parameterizations that add layers of uncertainty [e.g. @garrett1975space; @guthrie2013revisiting].

### Measuring turbulence

The most direct way of determining a nitrate flux is measuring the so-called "dissipation of turbulent kinetic energy" ($\epsilon$) traditionally using free-falling microstructure profilers [@lueck2002oceanic]. $\epsilon$ can also be estimated from finescale current shear (i.e. current profiles) or strain visible in CTD profiles [@guthrie2013revisiting]. Once $\epsilon$ is determined, its accuracy usually cited as being within a factor of two [@moum1995comparison], the vertical turbulent diffusivity can be calculated, following @osborn1980estimates, as

$$K_\rho = \Gamma\frac{\epsilon}{N^2}$$ {#eq:osborn}

where $N^2$ is the Brunt-Väisälä buoyancy frequency and $\Gamma\approx 0.2$ is the mixing coefficient that reflects how much of $\epsilon$ is available for adiabatic mixing. @Eq:osborn has a number of known issues, a major one being that $\Gamma$ is not constant. A variety of different parameterizations have been proposed [e.g. @shih2005parameterization; @bouffard2013diapycnal], with no clear alternative emerging. @Eq:osborn is hence the de facto standard [@gregg2018mixing], and in fact all turbulence-based estimates of the vertical nitrate flux compiled for this paper are based on it. Most often, $\Gamma=0.2$ is used, but e.g. @sundfjord2007observations used $\Gamma=0.12$ following recommendations in the literature consistent with their dataset (see references therein).

### Using the inorganic nitrate drawdown as an indicator of nitrate flux

Another method to determine vertical nitrate fluxes, less direct, uses a set of nitrate profiles through fall and winter [@randelhoff2015seasonal]. It has been employed to calculate two of the fluxes presented in this study. Vertically integrating the successive differences between them, one essentially reverses the calculation of net community production by the nitrate drawdown between winter and summer [@codispoti2013synthesis]. @randelhoff2015seasonal provided a brief overview over potentially interfering processes such as nitrogen fixation [@blais2012nitrogen] and concluded they were likely not significantly disturbing the annual budgets, but it has to be acknowledged that data is sparse. While this method may be robust in the pelagic, one can doubt its effectiveness in waters where nitrogen cycling is heavily affected by other processes, such as benthic processes in shallow waters, or coastal effects.


## New estimates of nitrate fluxes and new production in Young Sound, NE Greenland

### Methods

Sampling in the Young Sound/Tyrolerfjord system was conducted during three weeks in August 2015 from the Daneborg research station as part of the Danish MarineBasis program in Zackenberg ([@Fig:FN-NEW_YOUNGSOUND]A).

Water column nutrient samples were taken at 5 stations using a manually operated Niskin bottle from depths of 1, 5, 10, 20, 30, 40, 50, and 100 m. They were filtered with Whatman GF/F filters before being stored in previously acid-washed 30 mL high-density polyethylene (HDPE) plastic bottles and frozen until analysis (-18 °C). Nitrite (NO2) and nitrate (NO₃⁻) concentrations in each sample were measured on a Smartchem200 (AMS Alliance) autoanalyzer.

An MSS-90L (Sea and Sun Technology, Germany) free-falling microstructure profiler was deployed at a total of 37 stations, many of them repeat stations, to measure vertical profiles of the dissipation of turbulent kinetic energy. At the same stations, we deployed a SUNA (Satlantic) nitrate spectrophotometer to collect co-located vertical profiles of nitrate concentration. SUNA profiles were post-processed following [@randelhoff2016vertical] and calibrated using a constant bias determined from comparison with the nutrient water samples.

New and regenerated production were investigated at a subset of five stations. They were measured in two parallel incubations, labelled with ca. 10% ambient concentration of  ¹⁵NO₃⁻ and ¹⁵NH₄⁺ respectively. Water samples were incubated in triplicate 500 ml polycarbonate bottles in situ.  Additionally ca. 10% ambient concentration of ¹³C-bicarbonate was added to both sets of incubations to follow the incorporation of inorganic carbon into biomass. Samples were taken for  NO₂⁻+NO₃⁻ , ¹⁵NO₃⁻ and ¹⁵NH₄⁺  before and after addition of tracers by  filtering through a syringe filter (Whatman GF/C) into 10 ml polystyrene vials which were frozen (-18 °C) until analysis. After the incubation the particulate matter from each incubation vessel was filtered onto pre-combusted GF/F filters and later the ¹⁵N and ¹³C content of the particles on the filters was determined by mass spectrometry. Before filtration a third set of samples for NO₂⁻+NO₃⁻, ¹⁵NO₃⁻ and ¹⁵NH₄⁺ were taken. NO₂⁻+NO₃⁻ was determined photometrically following @schnetger2014determination. ¹⁵NH₄⁺ was determined based on @risgaard1995combined. ¹⁵NO₃⁻ was determined as in @kalvelage2011oxygen. New and regenerated production were calculated as the ratio of nitrate or ammonium to total N-uptake in each incubation respectively multiplied by the total C-uptake in each incubation.

In total, we collected 43 profiles of co-located SBE25+SUNA profiles, 103 MSS casts, 40 nutrient bottle samples and 20x3 triplicates of new and regenerated production incubations.

### Results

A freshwater layer was present throughout the fjord, but most prominent in the innermost parts ([@Fig:FN-NEW_YOUNGSOUND]B-D). Nitrate was depleted throughout the upper 40 m, below which concentrations steeply rose to about 4 µM. The fjord was remarkably quiescient in terms of turbulent dissipation rates, but mixing was significantly elevated over the sills. Vertical nitrate fluxes, computed for each station of co-located MSS and SUNA measurements, ranged from 0.012 to 13.26 mmol N m⁻² d⁻¹, with some of the values in the fjord interior being the lowest observed across this entire study. Median upward fluxes were 0.036 and 0.33 mmol N m⁻² d⁻¹ in the fjord interior and over the sills, respectively. Incubations, although only available at two depths (5 and 20 m), indicated new production rates on the order of 0.1 to 1 mmol N m⁻² d⁻¹ ([@Fig:FN-NEW_YOUNGSOUND]E).

## Nitrate flux estimate in the Laptev Sea

### Data description

Microstructure and nutrient measurements from the Laptev Sea were collected under the framework of the German-Russian “Laptev Sea System”-partnership in winter 2008 and the summers of 2011, 2014, and 2018 ([@Fig:FN-NEW_LAPTEV]B). The 2008 profile was averaged from measurements collected during the helicopter-supported “Transdrift 13” winter expedition (6 April to 10 May 2008) to the southeastern Laptev shelf. The summer nitrate profile was averaged from profiles collected during the “Transdrift 19” expedition on board the RV Jakov Smirnitsky in September 2011 [@bauch2018physical].

In 2014 microstructure turbulence profiles were collected on 19 September 2014 during the Transdrift 22-expedition aboard the RV Viktor Buinitsky (see Janout et al., to be submitted to this issue). The dissipation rates of turbulent kinetic energy ($\epsilon$) were derived from shear variance measured with a freely falling MSS-90L microstructure profiler manufactured by Sea and Sun Technology (SST, Germany). Vertical profiles of epsilon were calculated from the isotropic formula and spectral analysis of 1-s segments and subsequently averaged into 1-m bins. Turbulent vertical fluxes are based on a diapycnal eddy diffusivity with a constant mixing efficiency taken to be 0.2 [@osborn1980estimates]. For statistical robustness, the 2014 MSS profile shown in this paper was averaged from a series of five casts.

In 2018 a joint German-US-Russian expedition to the Eurasian Arctic was carried out aboard the RV Akademik Tryoshnikov from 18 August to 30 September 2018. The expedition combined the German-Russian CATS (Changing Arctic Transpolar System) and the US-Russian NABOS (Nansen Amundsen Basin Observing System) programs. The dissipation profile was again generated with a MSS-90L, while the nitrate profile was recorded with a Deep SUNA V2 nitrate profiler (Seabird Scientific) attached to the shipboard CTD/rosette.
These data files were then processed using a program (ISUSDataProcessor) developed by Ken Johnson (MBARI) that corrects the spectral data for temperature effects on the bromide absorption and applies a linear baseline correction to account for absorption by colored dissolved organic matter [@sakamoto2009improved]. SUNA nitrate concentrations were then compared with nitrate concentrations measured from discrete seawater samples collected at various depths above 20 and below 300 m depth where concentrations were sufficiently constant with depth. The full description of the methods is distributed with the data [@alkire2019ocean].

### Nitrate fluxes

Two representative profiles were selected to compute nitrate fluxes ([@Fig:FN-NEW_LAPTEV]A): Cast 59 and a co-located MSS profile, both sampled in 2018, and the 2014 MSS profiles and cast 62, also co-located but from separate years. For both profiles, we visually determined the nitracline, averaged ε over that interval, and computed the average nitrate and density gradients by a linear regression. The resulting nitrate fluxes were 0.014 and 0.017 mmol N m⁻² d⁻¹, and hence we entered the average value of 0.015 mmol N m⁻² d⁻¹ for the Laptev Sea into the nitrate fluxes compilation.

Even though we have a winter and a summer vertical profile of nitrate concentrations, we cannot calculate a winter flux using the integrated drawdown [@codispoti2013synthesis; @randelhoff2015seasonal] because comparison of the winter and summer profiles does not indicate any reliable vertical structure in the drawdown. This may indicate that winter fluxes might be too small to make a noticeable difference between the summer and winter profiles. More importantly, in such a shallow shelf sea, other factors (such as benthic nitrogen cycling or riverine freshwater) may also play a role as detailed above.

## Nitrate flux estimate in Baffin Bay

Three biogeochemical Argo floats, part of the NAOS project, overwintered in Baffin Bay from July 2017 to July 2018, described in detail by Randelhoff et al. (2020, in prep.).

Nitrate concentration was observed by the Satlantic Submersible Ultraviolet Nitrate Analyzer (SUNA). Each sensor's offset, taken to be constant and depth-independent [@randelhoff2016vertical], was corrected based on nitrate concentration profiles sampled during deployment of the floats. Mixed layer depth was defined as the shallowest depth where density rose more than 0.1 kg m⁻³ above the surface density.

Integrating the nitrate deficit $\Delta [NO₃⁻]\equiv [NO₃⁻](60 m) - [NO₃⁻](z)$ over the upper 60 meters for each station shows that over the course of four months (from November to March), a deficit of 200 mmol N m⁻² was replenished, approximately equivalent to an upward nitrate flux of 1.66 mmol N m⁻² d⁻¹ ([@Fig:FN-NEW_BAFFIN]). Although each float was drifting during the course of the winter, which may have introduced advective changes, the floats were well dispersed across Baffin Bay and should give a representative picture of winter mixed layer evolution. Details are deferred to the aforementioned manuscript (Randelhoff et al., in prep.). The usual caveats about neglecting mixed-layer regeneration and consumption of nutrients apply, and so this calculation makes the same kind of assumptions as have been detailed by @randelhoff2015seasonal.

# Figures

![{~~(A) Seasonal cycles of surface nitrate concentrations in different regions of the Arctic. (B) The delineation of these regions largely follows @codispoti2013synthesis and @peralta-ferriz2015seasonal.~>Seasonal cycles of surface nitrate concentrations in the Arctic Ocean. The lasso tool (upper right) permits selection of groups of points. Needs internet access to load the Javascript libraries.~~}](../nb_fig/FIGURE_NO3-COMP_chart_seasonal_cycle.{~~png~>html~~}){#fig:NO3-COMP_chart_seasonal_cycle}

![All nitrate flux compilation across the Arctic Ocean compiled for this study, irrespective of season and vertical levels. The smaller dots indicate single stations, whereas the big dots represent averages over larger time or space scales.](../nb_fig/FIGURE_FN-COMP_map.{~~png~>html~~}){#fig:FN-COMP_map}

![Vertical turbulent nitrate fluxes as a function of the month. Black lines mark the regions where the water column overturns in winter and orange those where it does not. Dotted lines reflect flux estimates based on small sample sizes (N), potentially not very representative of the regional or seasonal scale, whereas solid lines indicate data that are representative of a larger spatial or temporal scale.](../nb_fig/FIGURE_FN-COMP_chart_seasonal_cycle.{~~png~>html~~}){#fig:FN-COMP_chart_seasonal_cycle}

![The surface nitrate inventory dominated by variations in turbulent mixing. The annual pre-bloom surface nitrate concentration graphed as a function of (A) the vertical nitrate flux during winter and (B) the strength of water column stratification in the upper 30-60 m depth interval. The bold curves show average nitrate concentration for a given strength of stratification for either of three bathymetry types. Vertical bars (horizontally slightly offset to increase readability) indicate the standard deviation of data for each bin. Data sources: (A) nitrate flux compilation, (B) nitrate profile database.](../nb_fig/FIGURE_FN-COMP_chart_vs_NO3.{~~png~>html~~}){#fig:FN-COMP_chart_vs_NO3}

![Annual nitrogen fluxes in the Arctic surface ocean. Winter average upward nitrate flux, new production, and vertical downward particle export (converted to nitrogen units using the Redfield ratio) at 200 m depth compared across four regions of the Arctic Ocean. Data sources: Nitrate fluxes, see @Tbl:nitrate_fluxes; new production, @sakshaug2004primary; export production, @wiedmann2015potential, @honjo2010biological, and @cai2010low. Error bars were systematically only available for nitrate fluxes.](../nb_fig/FIGURE_PP_FN_NEWP_EXP_regional.{~~png~>html~~}){#fig:PP_FN_NEWP_EXP_regional}

![(A) New production incubations compared with upward nitrate flux for three case studies. Data sources: @randelhoff2016vertical, @nishino2015nutrient, this study (see Appendix). (B) Annual cycle of dissolved (DON) and particulate organic nitrogen (PON) observed in the seasonal ice zone of Fram Strait. Shaded areas indicate the standard deviation. Data source: @paulsen2018asynchronous, their Table 1.](../nb_fig/FIGURE_PP_incubations_vs_flux.{~~png~>html~~}){#fig:PP_incubations_vs_flux}

![Summer surface nitrate concentration.](../nb_fig/FIGURE_NO3-COMP_map_no3_summer.{~~png~>html~~}){#fig:NO3-COMP_map_no3_summer}

![Distributions (kernel density estimates) of observed nitrate fluxes based on Tables -@Tbl:nitrate_fluxes and -@Tbl:nitrate_fluxes_other. Note that these curves give each observation the same weight, regardless of areal or temporal scope.](../nb_fig/FIGURE_FN-COMP_comparison_world.{~~png~>html~~}){#fig:FN-COMP_comparison_world}

![A simplified marine nitrogen cycle and idealized Arctic hydrography. (A) General schematic of a vertical profile of nitrate concentration, along with the respective portion of the nitrogen cycle that takes place in each layer. In this idealized case, there is a clear separation between the seasonal variations in nitrate concentrations in the surface layer which give rise to the seasonal nitracline, and the underlying perennial nitracline. (B) In areas with deep overturning into the waters of maximum nitrate concentration, the deep nitracline ceases to be meaningful. Instead, nitrate fluxes tap into high-nutrient water every winter. (C) Highly stratified areas do not see large seasonal excursions in surface layer nitrate concentrations or mixing depths.](../fig/ncycle.png){#fig:ncycle width=50%}

![Young Sound data. (A) Bathymetry and coast data courtesy T. Vang and J. Bendtsen (@rysgaard2003physical; not included in the supplemental material). Transect starting in the inner end of the fjord, going over two sills and out into the Greenland Sea, demonstrating (B) low salinity due to ice sheet runoff, (C) nitrate depletion in the upper 30-40 meters, and (D) a quiescent fjord interior with vigorous mixing over the two sills. (E) Upward nitrate fluxes observed in Young Sound (shaded areas represent kernel density estimates) and observed values of new production, integrated over 0-20 meters (black bars). Note that new production estimates are based on only two measurement depths; see methods.](../nb_fig/FIGURE_FN-NEW_YOUNGSOUND.{~~png~>html~~}){#fig:FN-NEW_YOUNGSOUND}

![Laptev Sea data. (A) Vertical profiles of salinity, nitrate concentration and dissipation of turbulent kinetic energy ($\epsilon$) in the Laptev Sea. (B) Measurement locations in the Laptev Sea.](../nb_fig/FIGURE_FN-NEW_LAPTEV.{~~png~>html~~}){#fig:FN-NEW_LAPTEV}

![Seasonal cycle of nitrate concentrations in Baffin Bay alongside mixed layer depth (A) and the 0-60 m vertically integrated nitrate deficit $\Delta [NO₃⁻]=[NO₃⁻](60 m) - [NO₃⁻](z)$ (B).](../nb_fig/FIGURE_FN-NEW_BAFFIN.{~~png~>html~~}){#fig:FN-NEW_BAFFIN}

# Tables

Region|Season|NO₃⁻ flux\*|Reference|Sample size|Turbulence meas.|NO₃⁻ meas.
---|---|---|---|---|---|---
Amundsen Basin|Winter|0.05|@randelhoff2016regional|Large|Microstruct.|Optic
Baffin Bay|Winter|1.7|this study|Large|N/A|Optic
Barents Sea|Summer|0.1|@sundfjord2007observations|Small|Microstruct.|Bottle
Barents Sea|Summer|0.1|@wiedmann2017upward|Small|Microstruct.|Optic
Barents Sea|Summer|2.0|@sundfjord2007observations|Small|Microstruct.|Bottle
Barents Sea|Summer|5.0|@wiedmann2017upward|Small|Microstruct.|Optic
Barents Sea, AABC|Winter|2.5|@randelhoff2015seasonal|Large|N/A|Optic
Beaufort Sea |Winter|0.12|@bourgault2011turbulent|Large|Microstruct.|Optic
Canada Basin|Winter|0.01|@randelhoff2016regional|Large|Finestruct.|Optic
Chukchi Sea|Summer|0.02|this study, @nishino2015nutrient|Small|Microstruct.|Bottle
Chukchi Sea|Summer|0.19|@nishino2018biogeochemical|Large|Microstruct.|Bottle
Laptev Shelf (outer)|Summer|0.015|this study|Small|Microstruct.|Bottle & Optic
Makarov Basin|Winter|0.015|@randelhoff2016regional|Large|Finestruct.|Optic
N Svalbard/Fram Strait|Summer|0.3\*\*|@randelhoff2016vertical|Large|Microstruct.|Optic
N Svalbard/Fram Strait|Summer|0.7\*\*\*|@randelhoff2016vertical|Large|Microstruct.|Optic
Nansen Basin/Yermak Plateau|Winter|0.2|@randelhoff2016regional|Large|Microstruct.|Optic
Young Sound (Interior)|Summer|0.035|this study|Large|Microstruct.|Optic
Young Sound (Sills)|Summer|0.33|this study|Large|Microstruct.|Optic

: Nitrate fluxes observed in the Arctic Ocean. \* Turbulent vertical nitrate flux given in mmol N m⁻² d⁻¹. \*\* Under ice cover. \*\*\* Open water. AABC: Anticyclonic Arctic Boundary Current. Perennial: Measured below the extent of seasonal nitrate variation. See {~~Supplementary Material~>[the data file](data/fn-compilation.csv)~~} for complete data set. {#tbl:nitrate_fluxes}

\
\


Reference|NO₃⁻ flux\*|Region
---|---|---
@lewis1986vertical|0.14|Subtropical North Atlantic
@jenkins1988nitrate|1.6|Subtropical North Atlantic
@hamilton1989vertical re-analyzing @lewis1986vertical|0.85|Subtropical North Atlantic
@carr1995physical|1.9|Equatorial Pacific (5 °N - 5 °S)
@carr1995physical|4.3|Equatorial Pacific (1 °N - 1 °S)
@horne1996turbulence|0.047|North Atlantic, Georges Bank
@horne1996turbulence|0.18|North Atlantic, Georges Bank
@planas1999nitrate|0.38|Central Atlantic
@law2001lagrangian|1.8|Subarctic North Atlantic
@sharples2001internal|12.0|New Zealand Shelf
@law2003vertical|0.17|Antarctic Circumpolar Current
@hales2005irreversible|9.0|Oregon Shelf Upwelling System
@sharples2007springneap|1.3|Celtic Sea shelf edge (neap tide)
@sharples2007springneap|9.0|Celtic Sea shelf edge (spring tide)
@hales2009turbulent|0.9|New England shelf break front (seaward side)
@hales2009turbulent|5.2|New England shelf break front (shoreward side)
@rippeth2009diapcynal|1.5|Irish Sea
@martin2010supply|0.09|North Atlantic, Porcupine Abyssal Plain
@schafstall2010tidalinduced|1.0|Mauritanian Upwelling (offshore)
@schafstall2010tidalinduced|3.7|Mauritanian Upwelling (shelf)
@schafstall2010tidalinduced|10.0|Mauritanian Upwelling (slope)
@shiozaki2011imbalance|0.25|North Pacific, East China Sea shelf
@kaneko2013observations|0.003|North Pacific, Kuroshio (south of front)
@kaneko2013observations|0.34|North Pacific, Kuroshio (north of front)
@cyr2015turbulent|0.21|St. Lawrence Gulf, Canada
@cyr2015turbulent|95.0|St. Lawrence Gulf, Canada (shallow sill)

: Nitrate fluxes in the global ocean, excluding the Arctic. \* Turbulent vertical nitrate flux given in mmol N m⁻² d⁻¹. {#tbl:nitrate_fluxes_other}


# References
